@@ -1,12 +1,22 @@
 ##
 ##
+#
+# SOFTWARE HISTORY
+#
+# Date          Ticket#  Engineer  Description
+# ------------- -------- --------- ---------------------------------------------
+# Feb 13, 2017  6092     randerso  Added StoreTimeAction
+#
+##
 
 import argparse
 import sys
+import time
 
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataplugin.gfe.db.objects import DatabaseID
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataplugin.gfe.db.objects import ParmID
 
+TIME_FORMAT = "%Y%m%d_%H%M"
 
 class UsageArgumentParser(argparse.ArgumentParser):
     """
@@ -39,3 +49,16 @@ class AppendParmNameAndLevelAction(argparse.Action):
         else:
             setattr(namespace, self.dest, [comp])
 
+class StoreTimeAction(argparse.Action):
+    """
+    argparse.Action subclass to validate GFE formatted time strings
+    and parse them to time.struct_time
+    """
+    def __call__(self, parser, namespace, values, option_string=None):
+        try:
+            timeStruct = time.strptime(values, TIME_FORMAT)
+        except:
+            parser.error(str(values) + " is not a valid time string of the format YYYYMMDD_hhmm")
+
+        setattr(namespace, self.dest, timeStruct)
+
