@@ -320,6 +320,8 @@ nexrad = {
 		"name": "Digital Hybrid Scan Refl",
 		"res": 1.0,
 		"mnemo": "DHR",
+		"ctable": ['NWSStormClearReflectivity', -20., 0.5],
+		"scale": [-32.0, 94.5],
 		"range": 230,
 		"lvls": 256,
 		"id": 32,
@@ -1324,8 +1326,6 @@ nexrad = {
 		"name": "Hybrid Hydrometeor Class",
 		"res": 0.25,
 		"mnemo": "HHC",
-		"ctable": ['NWS8bitVel', -100., 1.],
-		"scale": [0, 16],
 		"range": 230,
 		"lvls": 256,
 		"id": 177,
@@ -1473,39 +1473,50 @@ nexrad = {
 	}
 }
 
+#
 # Dictionary that maps VTEC codes to headlines
 # Modified from com.raytheon.uf.edex.activetable/utility/common_static/base/vtec/VTECTable.py
-# Colors from https://www.weather.gov/bro/mapcolors
+# Colornames from:
+# 1) https://www.weather.gov/bro/mapcolors
+# 2) https://digital.weather.gov/staticpages/definitions.php
+# 3) https://www.w3schools.com/colors/colors_names.asp
+#
 vtec = {
     'AF.W' : {'phen': 'AF',
               'sig': 'W',
+              'color': 'gray',
               'hdln': 'Ashfall Warning'},
     'AF.Y' : {'phen': 'AF',
               'sig': 'Y',
-              'gray'
+              'color': 'gray',
               'hdln': 'Ashfall Advisory'},
     'AQ.Y' : {'phen': 'AQ',
               'sig': 'Y',
+              'color': 'gray',
               'hdln': 'Air Quality Alert'},
     'AS.O' : {'phen': 'AS',
               'sig': 'O',
+              'color': 'gray',
               'hdln': 'Air Stagnation Outlook'},
     'AS.Y' : {'phen': 'AS',
               'sig': 'Y',
+              'color': 'gray',
               'hdln': 'Air Stagnation Advisory'},
     'BH.S' : {'phen': 'BH',
               'sig': 'S',
+              'color': 'turquoise',
               'hdln': 'Beach Hazards Statement'},
     'BW.Y' : {'phen': 'BW',
               'sig': 'Y',
+              'color': 'thistle',
               'hdln': 'Brisk Wind Advisory'},
     'BZ.A' : {'phen' : 'BZ',
               'sig' : 'A',
-              'color': 'orangered',
+              'color': 'greenyellow',
               'hdln' : 'Blizzard Watch'},
     'BZ.W' : {'phen' : 'BZ',
               'sig' : 'W',
-              'color': 'greenyellow',
+              'color': 'orangered',
               'hdln' : 'Blizzard Warning'},
     'CF.A' : {'phen': 'CF',
               'sig': 'A',
@@ -1533,15 +1544,19 @@ vtec = {
               'hdln': 'Blowing Dust Advisory'},
     'EC.A' : {'phen': 'EC',
               'sig': 'A',
+              'color': 'blue',
               'hdln': 'Extreme Cold Watch'},
     'EC.W' : {'phen': 'EC',
               'sig': 'W',
+              'color': 'blue',
               'hdln': 'Extreme Cold Warning'},
     'EH.A' : {'phen': 'EH',
               'sig': 'A',
+              'color': 'maroon',
               'hdln': 'Excessive Heat Watch'},
     'EH.W' : {'phen': 'EH',
               'sig': 'W',
+              'color': 'mediumvioletred',
               'hdln': 'Excessive Heat Warning'},
     'EW.W' : {'phen': 'EW',
               'sig': 'W',
@@ -1597,6 +1612,7 @@ vtec = {
               'hdln': 'Flood Advisory'},
     'FR.Y' : {'phen': 'FR',
               'sig': 'Y',
+              'color': 'cornflowerblue',
               'hdln': 'Frost Advisory'},
     'FW.A' : {'phen': 'FW',
               'sig': 'A',
@@ -1664,33 +1680,43 @@ vtec = {
               'hdln': 'Hard Freeze Warning'},
     'IS.W' : {'phen': 'IS',
               'sig': 'W',
+              'color': 'darkmagenta',
               'hdln': 'Ice Storm Warning'},
     'LE.A' : {'phen': 'LE',
               'sig': 'A',
+              'color': 'LightSkyBlue',
               'hdln': 'Lake Effect Snow Watch'},
     'LE.W' : {'phen': 'LE',
               'sig': 'W',
+              'color': 'DarkCyan',
               'hdln': 'Lake Effect Snow Warning'},
     'LE.Y' : {'phen': 'LE',
               'sig': 'Y',
+              'color': 'MediumTurquoise',
               'hdln': 'Lake Effect Snow Advisory'},
     'LO.Y' : {'phen': 'LO',
               'sig': 'Y',
+              'color': 'maroon',
               'hdln': 'Low Water Advisory'},
     'LS.A' : {'phen': 'LS',
               'sig': 'A',
+              'color': 'MediumAquaMarine',
               'hdln': 'Lakeshore Flood Watch'},
     'LS.S' : {'phen': 'LS',
               'sig': 'S',
+              'color': 'lawngreen',
               'hdln': 'Lakeshore Flood Statement'},
     'LS.W' : {'phen': 'LS',
               'sig': 'W',
+              'color': 'forestgreen',
               'hdln': 'Lakeshore Flood Warning'},
     'LS.Y' : {'phen': 'LS',
               'sig': 'Y',
+              'color': 'lawngreen',
               'hdln': 'Lakeshore Flood Advisory'},
     'LW.Y' : {'phen': 'LW',
               'sig': 'Y',
+              'color': 'tan',
               'hdln': 'Lake Wind Advisory'},
     'MA.A' : {'phen': 'MA',
               'sig': 'A',
@@ -1706,18 +1732,23 @@ vtec = {
               'hdln': 'Special Marine Warning'},
     'MF.Y' : {'phen': 'MF',
               'sig': 'Y',
+              'color': 'slategray',
               'hdln': 'Dense Fog Advisory'}, # Marine Fog
     'MH.W' : {'phen': 'MH',
               'sig': 'W',
+              'color': 'darkgray',
               'hdln': 'Ashfall Warning'}, # Marine Ashfall
     'MH.Y' : {'phen': 'MH',
               'sig': 'Y',
+              'color': 'dimgray',
               'hdln': 'Ashfall Advisory'}, # Marine Ashfall
     'MS.Y' : {'phen': 'MS',
               'sig': 'Y',
+              'color': 'khaki',
               'hdln': 'Dense Smoke Advisory'}, # Marine Smoke
     'RB.Y' : {'phen': 'RB',
               'sig': 'Y',
+              'color': 'thistle',
               'hdln': 'Small Craft Advisory for rough bar'},
     'RP.S' : {'phen': 'RP',
               'sig' : 'S',
@@ -1729,9 +1760,11 @@ vtec = {
               'hdln': 'Small Craft Advisory'},
     'SE.A' : {'phen': 'SE',
               'sig': 'A',
+              'color': 'darkslateblue',
               'hdln': 'Hazardous Seas Watch'},
     'SE.W' : {'phen': 'SE',
               'sig': 'W',
+              'color': 'thistle',
               'hdln': 'Hazardous Seas Warning'},
     'SI.Y' : {'phen': 'SI',
               'sig': 'Y',
@@ -1739,7 +1772,7 @@ vtec = {
               'hdln': 'Small Craft Advisory for winds'},
     'SM.Y' : {'phen': 'SM',
               'sig': 'Y',
-              'khaki'
+              'color': 'khaki',
               'hdln': 'Dense Smoke Advisory'},
     'SR.A' : {'phen': 'SR',
               'sig': 'A',
@@ -1751,9 +1784,11 @@ vtec = {
               'hdln': 'Storm Warning'},
     'SS.A' : {'phen': 'SS',
               'sig': 'A',
+              'color': '#DB7FF7',
               'hdln': 'Storm Surge Watch'},
     'SS.W' : {'phen': 'SS',
               'sig': 'W',
+              'color': '#B524F7',
               'hdln': 'Storm Surge Warning'},
     'SU.W' : {'phen': 'SU',
               'sig': 'W',
@@ -1797,27 +1832,35 @@ vtec = {
               'hdln': 'Tropical Storm Warning'},
     'TS.A' : {'phen': 'TS',
               'sig': 'A',
+              'color': 'fuchsia',
               'hdln': 'Tsunami Watch'},
     'TS.W' : {'phen': 'TS',
               'sig': 'W',
+              'color': '#FD6347',
               'hdln': 'Tsunami Warning'},
     'TS.Y' : {'phen': 'TS',
               'sig': 'Y',
+              'color': 'chocolate',
               'hdln': 'Tsunami Advisory'},
     'TY.A' : {'phen': 'TY',
               'sig': 'A',
+              'color': 'fuchsia',
               'hdln': 'Typhoon Watch'},
     'TY.W' : {'phen': 'TY',
               'sig': 'W',
+              'color': '#FD6347',
               'hdln': 'Typhoon Warning'},
     'UP.A' : {'phen': 'UP',
               'sig': 'A',
+              'color': 'RosyBrown',
               'hdln': 'Heavy Freezing Spray Watch'},
     'UP.W' : {'phen': 'UP',
               'sig': 'W',
+              'color': '#00C0FF',
               'hdln': 'Heavy Freezing Spray Warning'},
     'UP.Y' : {'phen': 'UP',
               'sig': 'Y',
+              'color': '#00C0FF',
               'hdln': 'Freezing Spray Advisory'},
     'WC.A' : {'phen': 'WC',
               'sig': 'A',
@@ -1849,9 +1892,11 @@ vtec = {
               'hdln': 'Winter Weather Advisory'},
     'ZF.Y' : {'phen': 'ZF',
               'sig': 'Y',
+              'color': 'teal',
               'hdln': 'Freezing Fog Advisory'},
     'ZR.Y' : {'phen': 'ZR',
               'sig': 'Y',
+              'color': 'orchid',
               'hdln': 'Freezing Rain Advisory'},
     }
 
@@ -1920,7 +1965,7 @@ upgradeHazardsDict = {
 def checkForUpgrade(pPhen, pSig, cPhen, cSig):
     proposed = pPhen + "." + pSig
     current = cPhen + "." + cSig
-    if upgradeHazardsDict.has_key(proposed):
+    if proposed in upgradeHazardsDict:
         if current in upgradeHazardsDict[proposed]:
             return 1
         else:
@@ -1971,7 +2016,7 @@ downgradeHazardsDict = {
 def checkForDowngrade(pPhen, pSig, cPhen, cSig):
     proposed = pPhen + "." + pSig
     current = cPhen + "." + cSig
-    if downgradeHazardsDict.has_key(proposed):
+    if proposed in downgradeHazardsDict:
         if current in downgradeHazardsDict[proposed]:
             return 1
         else:
