@@ -12,7 +12,7 @@
 # match what they should be in the destination language.
 #
 #
-#     SOFTWARE HISTORY
+#    SOFTWARE HISTORY
 #
 #    Date            Ticket#       Engineer       Description
 #    ------------    ----------    -----------    --------------------------
@@ -20,18 +20,27 @@
 #    06/12/13         #2099        dgilling      Implement readObject() and
 #                                                writeObject().
 #    Apr 24, 2015    4425          nabowle       Add Double support
+#    Oct 17, 2016    5919          njensen       Optimized for speed
+#    Sep 06, 2018                  mjames@ucar   Python3 compliance
 #
 #
 
 from thrift.Thrift import TType
-import inspect, sys, types
+import inspect
+import sys
+import types
+import time
+import numpy
+import collections
 import dynamicserialize
 from dynamicserialize import dstypes, adapters
 from dynamicserialize import SelfDescribingBinaryProtocol
-import numpy
-import collections
+
+DS_LEN = len('dynamicserialize.dstypes.')
 
 dsObjTypes = {}
+
+
 def buildObjMap(module):
     if '__all__' in module.__dict__:
         for i in module.__all__:
@@ -42,7 +51,7 @@ def buildObjMap(module):
         clzName = module.__name__[module.__name__.rfind('.') + 1:]
         clz = module.__dict__[clzName]
         tname = module.__name__
-        tname = tname.replace('dynamicserialize.dstypes.', '')
+        tname = tname[DS_LEN:]
         dsObjTypes[tname] = clz
 
 buildObjMap(dstypes)
@@ -55,7 +64,7 @@ pythonToThriftMap = {
     dict: TType.MAP,
     type(set([])): TType.SET,
     float: SelfDescribingBinaryProtocol.FLOAT,
-    #types.FloatType: TType.DOUBLE,
+    # types.FloatType: TType.DOUBLE,
     bool: TType.BOOL,
     object: TType.STRUCT,
     str: TType.STRING,
@@ -71,7 +80,9 @@ pythonToThriftMap = {
     numpy.int64: TType.I64
 }
 
-primitiveSupport = (TType.BYTE, TType.I16, TType.I32, TType.I64, SelfDescribingBinaryProtocol.FLOAT, TType.DOUBLE)
+primitiveSupport = (TType.BYTE, TType.I16, TType.I32, TType.I64,
+                    SelfDescribingBinaryProtocol.FLOAT, TType.DOUBLE)
+
 
 class ThriftSerializationContext(object):
 
@@ -79,52 +90,51 @@ class ThriftSerializationContext(object):
         self.serializationManager = serializationManager
         self.protocol = selfDescribingBinaryProtocol
         self.typeDeserializationMethod = {
-                                    TType.STRING: self.protocol.readString,
-                                    TType.I16: self.protocol.readI16,
-                                    TType.I32: self.protocol.readI32,
-                                    TType.LIST: self._deserializeArray,
-                                    TType.MAP: self._deserializeMap,
-                                    TType.SET: self._deserializeSet,
-                                    SelfDescribingBinaryProtocol.FLOAT: self.protocol.readFloat,
-                                    TType.BYTE: self.protocol.readByte,
-                                    TType.I64: self.protocol.readI64,
-                                    TType.DOUBLE: self.protocol.readDouble,
-                                    TType.BOOL: self.protocol.readBool,
-                                    TType.STRUCT: self.deserializeMessage,
-                                    TType.VOID: lambda: None
-                                    }
+            TType.STRING: self.protocol.readString,
+            TType.I16: self.protocol.readI16,
+            TType.I32: self.protocol.readI32,
+            TType.LIST: self._deserializeArray,
+            TType.MAP: self._deserializeMap,
+            TType.SET: self._deserializeSet,
+            SelfDescribingBinaryProtocol.FLOAT: self.protocol.readFloat,
+            TType.BYTE: self.protocol.readByte,
+            TType.I64: self.protocol.readI64,
+            TType.DOUBLE: self.protocol.readDouble,
+            TType.BOOL: self.protocol.readBool,
+            TType.STRUCT: self.deserializeMessage,
+            TType.VOID: lambda: None
+        }
         self.typeSerializationMethod = {
-                                    TType.STRING: self.protocol.writeString,
-                                    TType.I16: self.protocol.writeI16,
-                                    TType.I32: self.protocol.writeI32,
-                                    TType.LIST: self._serializeArray,
-                                    TType.MAP: self._serializeMap,
-                                    TType.SET: self._serializeSet,
-                                    SelfDescribingBinaryProtocol.FLOAT: self.protocol.writeFloat,
-                                    TType.BYTE: self.protocol.writeByte,
-                                    TType.I64: self.protocol.writeI64,
-                                    TType.DOUBLE: self.protocol.writeDouble,
-                                    TType.BOOL: self.protocol.writeBool,
-                                    TType.STRUCT: self.serializeMessage,
-                                    TType.VOID: lambda x: None
-                                    }
+            TType.STRING: self.protocol.writeString,
+            TType.I16: self.protocol.writeI16,
+            TType.I32: self.protocol.writeI32,
+            TType.LIST: self._serializeArray,
+            TType.MAP: self._serializeMap,
+            TType.SET: self._serializeSet,
+            SelfDescribingBinaryProtocol.FLOAT: self.protocol.writeFloat,
+            TType.BYTE: self.protocol.writeByte,
+            TType.I64: self.protocol.writeI64,
+            TType.DOUBLE: self.protocol.writeDouble,
+            TType.BOOL: self.protocol.writeBool,
+            TType.STRUCT: self.serializeMessage,
+            TType.VOID: lambda x: None
+        }
         self.listDeserializationMethod = {
-                                    TType.BYTE: self.protocol.readI8List,
-                                    TType.I16: self.protocol.readI16List,
-                                    TType.I32: self.protocol.readI32List,
-                                    TType.I64: self.protocol.readI64List,
-                                    SelfDescribingBinaryProtocol.FLOAT: self.protocol.readF32List,
-                                    TType.DOUBLE: self.protocol.readF64List
-                                    }
+            TType.BYTE: self.protocol.readI8List,
+            TType.I16: self.protocol.readI16List,
+            TType.I32: self.protocol.readI32List,
+            TType.I64: self.protocol.readI64List,
+            SelfDescribingBinaryProtocol.FLOAT: self.protocol.readF32List,
+            TType.DOUBLE: self.protocol.readF64List
+        }
         self.listSerializationMethod = {
-                                    TType.BYTE: self.protocol.writeI8List,
-                                    TType.I16: self.protocol.writeI16List,
-                                    TType.I32: self.protocol.writeI32List,
-                                    TType.I64: self.protocol.writeI64List,
-                                    SelfDescribingBinaryProtocol.FLOAT: self.protocol.writeF32List,
-                                    TType.DOUBLE: self.protocol.writeF64List
-                                    }
-
+            TType.BYTE: self.protocol.writeI8List,
+            TType.I16: self.protocol.writeI16List,
+            TType.I32: self.protocol.writeI32List,
+            TType.I64: self.protocol.writeI64List,
+            SelfDescribingBinaryProtocol.FLOAT: self.protocol.writeF32List,
+            TType.DOUBLE: self.protocol.writeF64List
+        }
 
     def readMessageStart(self):
         msg = self.protocol.readMessageBegin()
@@ -140,13 +150,14 @@ class ThriftSerializationContext(object):
         if name.isdigit():
             obj = self._deserializeType(int(name))
             return obj
-        elif name in adapters.classAdapterRegistry:
+        if name in adapters.classAdapterRegistry:
             return adapters.classAdapterRegistry[name].deserialize(self)
-        elif name.find('$') > -1:
-            # it's an inner class, we're going to hope it's an enum, treat it special
+        elif '$' in name:
+            # it's an inner class, we're going to hope it's an enum, treat it
+            # special
             fieldName, fieldType, fieldId = self.protocol.readFieldBegin()
             if fieldName.decode('utf8') != '__enumValue__':
-                raise dynamicserialize.SerializationException(b"Expected to find enum payload.  Found: " + fieldName)
+                raise dynamicserialize.SerializationException("Expected to find enum payload.  Found: " + fieldName)
             obj = self.protocol.readString()
             self.protocol.readFieldEnd()
             return obj
@@ -161,38 +172,31 @@ class ThriftSerializationContext(object):
         return obj
 
     def _deserializeType(self, b):
-        if b in self.typeDeserializationMethod:
+        try:
             return self.typeDeserializationMethod[b]()
-        else:
-            raise dynamiceserialize.SerializationException("Unsupported type value " + str(b))
-
+        except KeyError:
+            raise dynamicserialize.SerializationException(
+                "Unsupported type value " + str(b))
 
     def _deserializeField(self, structname, obj):
         fieldName, fieldType, fieldId = self.protocol.readFieldBegin()
         if fieldType == TType.STOP:
             return False
         elif fieldType != TType.VOID:
-#            if adapters.fieldAdapterRegistry.has_key(structname) and adapters.fieldAdapterRegistry[structname].has_key(fieldName):
-#                result = adapters.fieldAdapterRegistry[structname][fieldName].deserialize(self)
-#            else:
             result = self._deserializeType(fieldType)
             fn_str = bytes.decode(fieldName)
             lookingFor = "set" + fn_str[0].upper() + fn_str[1:]
 
             try:
                 setMethod = getattr(obj, lookingFor)
-
-                if isinstance(setMethod, collections.Callable):
-                    setMethod(result)
-                else:
-                    raise SerializationException("Couldn't find setter method " + lookingFor)
+                setMethod(result)
             except:
-                raise SerializationException("Couldn't find setter method " + lookingFor)
+                raise dynamicserialize.SerializationException(
+                    "Couldn't find setter method " + lookingFor)
 
         self.protocol.readFieldEnd()
         return True
 
-
     def _deserializeArray(self):
         listType, size = self.protocol.readListBegin()
         result = []
@@ -229,16 +233,17 @@ class ThriftSerializationContext(object):
         pyt = type(obj)
         if pyt in pythonToThriftMap:
             return pythonToThriftMap[pyt]
-        elif pyt.__module__.startswith('dynamicserialize.dstypes'):
+        elif pyt.__module__[:DS_LEN - 1] == ('dynamicserialize.dstypes'):
             return pythonToThriftMap[object]
         else:
-            raise dynamicserialize.SerializationException("Don't know how to serialize object of type: " + str(pyt))
+            raise dynamicserialize.SerializationException(
+                "Don't know how to serialize object of type: " + str(pyt))
 
     def serializeMessage(self, obj):
-        
         tt = self._lookupType(obj)
+
         if tt == TType.STRUCT:
-            fqn = obj.__module__.replace('dynamicserialize.dstypes.', '')
+            fqn = obj.__module__[DS_LEN:]
             if fqn in adapters.classAdapterRegistry:
                 # get proper class name when writing class name to serialization stream
                 # in case we have a special inner-class case
@@ -259,7 +264,7 @@ class ThriftSerializationContext(object):
                         val = m[1]()
                         ft = self._lookupType(val)
                         if ft == TType.STRUCT:
-                            fc = val.__module__.replace('dynamicserialize.dstypes.', '')
+                            fc = val.__module__[DS_LEN:]
                             self._serializeField(fieldname, ft, fid, val)
                         else:
                             self._serializeField(fieldname, ft, fid, val)
@@ -274,24 +279,23 @@ class ThriftSerializationContext(object):
             self.protocol.writeStructEnd()
 
     def _serializeField(self, fieldName, fieldType, fieldId, fieldValue):
-        #print("SERFIELD", fieldName, fieldType, fieldId, fieldValue)
         self.protocol.writeFieldBegin(fieldName, fieldType, fieldId)
         self._serializeType(fieldValue, fieldType)
         self.protocol.writeFieldEnd()
-        #print(self.protocol)
 
     def _serializeType(self, fieldValue, fieldType):
         if fieldType in self.typeSerializationMethod:
             return self.typeSerializationMethod[fieldType](fieldValue)
         else:
-            raise dynamicserialize.SerializationException("Unsupported type value " + str(fieldType))
+            raise dynamicserialize.SerializationException(
+                "Unsupported type value " + str(fieldType))
 
     def _serializeArray(self, obj):
         size = len(obj)
         if size:
             if type(obj) is numpy.ndarray:
-               t = pythonToThriftMap[obj.dtype.type]
-               size = obj.size
+                t = pythonToThriftMap[obj.dtype.type]
+                size = obj.size
             else:
                 t = self._lookupType(obj[0])
         else:
@@ -319,7 +323,6 @@ class ThriftSerializationContext(object):
             self.listSerializationMethod[t](obj)
         self.protocol.writeListEnd()
 
-
     def _serializeMap(self, obj):
         size = len(obj)
         self.protocol.writeMapBegin(TType.VOID, TType.VOID, size)
