@@ -10,7 +10,6 @@
 ##
 
 __all__ = [
-            'GridDataHistory',
             'config',
             'db',
             'discrete',
@@ -19,7 +18,8 @@ __all__ = [
             'server',
             'slice',
             'svcbu',
-            'weather'
+            'weather',
+            'GridDataHistory'
           ]
 
 from .GridDataHistory import GridDataHistory
