@@ -26,15 +26,16 @@ __all__ = [
             'GetSelectTimeRangeRequest',
             'GetSingletonDbIdsRequest',
             'GetSiteTimeZoneInfoRequest',
+            'GfeClientRequest',
             'GridLocRequest',
             'IscDataRecRequest',
             'LockChangeRequest',
             'ProcessReceivedConfRequest',
             'ProcessReceivedDigitalDataRequest',
             'PurgeGfeGridsRequest',
-            'SaveASCIIGridsRequest',
-            'SmartInitRequest',
             'RsyncGridsToCWFRequest',
+            'SaveASCIIGridsRequest',
+            'SmartInitRequest'
           ]
 
 from .AbstractGfeRequest import AbstractGfeRequest
@@ -54,6 +55,7 @@ from .GetParmListRequest import GetParmListRequest
 from .GetSelectTimeRangeRequest import GetSelectTimeRangeRequest
 from .GetSingletonDbIdsRequest import GetSingletonDbIdsRequest
 from .GetSiteTimeZoneInfoRequest import GetSiteTimeZoneInfoRequest
+from .GfeClientRequest import GfeClientRequest
 from .GridLocRequest import GridLocRequest
 from .IscDataRecRequest import IscDataRecRequest
 from .LockChangeRequest import LockChangeRequest
