@@ -10,7 +10,7 @@
 ##
 
 __all__ = [
-            'JobProgress',
+            'JobProgress'
           ]
 
 from .JobProgress import JobProgress
